Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(505)

Unified Diff: media/base/async_filter_factory_base.h

Issue 6686061: PipelineError is dead. Long live PipelineStatus! (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: responses to 2nd CR Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/base/async_filter_factory_base.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/async_filter_factory_base.h
diff --git a/media/base/async_filter_factory_base.h b/media/base/async_filter_factory_base.h
index 75617f43125fbe02ced9667efdba2a60a6ac82a5..d800284d3f33348fbd790df2c7be045288dbf23b 100644
--- a/media/base/async_filter_factory_base.h
+++ b/media/base/async_filter_factory_base.h
@@ -74,17 +74,17 @@ class AsyncDataSourceFactoryBase : public DataSourceFactory {
void Start(RequestDoneCallback* done_callback);
// Derived objects call this method to indicate that the build request
// has completed. If the build was successful |error| should be set to
// PIPELINE_OK and |data_source| should contain the DataSource object
// that was built by this request. Ownership of |data_source| is being
// passed in this call. If an error occurs during the build process, this
- // method should be called with |error| set to an appropriate status code
+ // method should be called with |status| set to an appropriate status code
// and |data_source| set to NULL.
//
// The derived object should be in a state where it can be deleted from
// within this call. This class as well AsyncDataSourceFactoryBase use this
// method to cleanup state associated with this request.
- void RequestComplete(media::PipelineError error, DataSource* data_source);
+ void RequestComplete(media::PipelineStatus status, DataSource* data_source);
protected:
// Implemented by the derived object to start the build. Called by Start().
@@ -111,7 +111,7 @@ class AsyncDataSourceFactoryBase : public DataSourceFactory {
BuildCallback* callback) = 0;
private:
- void RunAndDestroyCallback(PipelineError error,
+ void RunAndDestroyCallback(PipelineStatus status,
BuildCallback* callback) const;
typedef Callback1<BuildRequest*>::Type RequestDoneCallback;
« no previous file with comments | « no previous file | media/base/async_filter_factory_base.cc » ('j') | no next file with comments »
@@ -74,17 +74,17 @@ class AsyncDataSourceFactoryBase : public DataSourceFactory {
void Start(RequestDoneCallback* done_callback);
// Derived objects call this method to indicate that the build request
- // has completed. If the build was successful |error| should be set to
+ // has completed. If the build was successful |status| should be set to
// PIPELINE_OK and |data_source| should contain the DataSource object
// that was built by this request. Ownership of |data_source| is being

Powered by Google App Engine
This is Rietveld 408576698